# DES02 - Database Design

Thiết kế database: schema design, normalization, indexing, data modeling.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [Schema Design](DES02-BP01-Schema-Design.md) | Thiết kế schema và normalization |
| BP02 | [Indexing Strategy](DES02-BP02-Indexing-Strategy.md) | Chiến lược đánh index tối ưu |

## Tham khảo

- Database Design for Mere Mortals
- SQL Antipatterns
- High Performance MySQL
